Title Pool meta-analysis estimates and estimates from a regression model.
pool_splines(
v,
meta.df,
glm.res,
cor.m = NULL,
x.range = NULL,
full.output = FALSE
)List containing pooled estimates of the spline parameters.
Name of the covariate, which is modeled using an nsk spline (see package splines2).
Meta-analysis estimates: dataframe with columns est (e.g. log HR estimate), est.var (estimated variance), variable (name of the covariate used in the spline) and cov.value (covariate value at which est and est.var were reported).
Regression analysis result object.
Assumed correlation matrix. If NULL (default) or NA then use correlation matrix from glm.res.
If NULL (default), then take the range from meta.df, otherwise give range as a vector with two components.
If TRUE then output also the log HR values and 95% confidence intervals over a grid of covariate values.